Module blaxel.models.knowledgebase_spec
=======================================

Classes
-------

`KnowledgebaseSpec(collection_name: blaxel.types.Unset | str = <blaxel.types.Unset object>, embedding_model: blaxel.types.Unset | str = <blaxel.types.Unset object>, embedding_model_type: blaxel.types.Unset | str = <blaxel.types.Unset object>, enabled: blaxel.types.Unset | bool = <blaxel.types.Unset object>, integration_connections: blaxel.types.Unset | list[str] = <blaxel.types.Unset object>, options: blaxel.types.Unset | ForwardRef('KnowledgebaseSpecOptions') = <blaxel.types.Unset object>, policies: blaxel.types.Unset | list[str] = <blaxel.types.Unset object>, revision: blaxel.types.Unset | ForwardRef('RevisionConfiguration') = <blaxel.types.Unset object>, sandbox: blaxel.types.Unset | bool = <blaxel.types.Unset object>)`
:   Knowledgebase specification
    
    Attributes:
        collection_name (Union[Unset, str]): Collection name
        embedding_model (Union[Unset, str]): Embedding model
        embedding_model_type (Union[Unset, str]): Embedding model type
        enabled (Union[Unset, bool]): Enable or disable the agent
        integration_connections (Union[Unset, list[str]]):
        options (Union[Unset, KnowledgebaseSpecOptions]): Options specific to the knowledge base
        policies (Union[Unset, list[str]]):
        revision (Union[Unset, RevisionConfiguration]): Revision configuration
        sandbox (Union[Unset, bool]): Sandbox mode
    
    Method generated by attrs for class KnowledgebaseSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `collection_name`
    :

    `embedding_model`
    :

    `embedding_model_type`
    :

    `enabled`
    :

    `integration_connections`
    :

    `options`
    :

    `policies`
    :

    `revision`
    :

    `sandbox`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :